@@ -10,14 +10,14 @@
 #' @return an object of class \code{\link{Date}}.
 #' @author Janne Huovari \email{janne.huovari@@ptt.fi}
 #' @examples \dontrun{
-#'    lp <- get_eurostat("namq_aux_lp", time_format = "raw")
-#'    lp$time <- eurotime2date(x = lp$time)
+#'    na_q <- get_eurostat("namq_10_pc", time_format = "raw")
+#'    na_q$time <- eurotime2date(x = na_q$time)
 #'    
 #'    un <- get_eurostat("une_rt_m", time_format = "raw")
 #'    un$time <- eurotime2date(x = un$time)
 #'    
-#'    lpa <- get_eurostat("nama_aux_lp", time_format = "raw")
-#'    lpa$time <- eurotime2date(x = lpa$time)
+#'    na_a <- get_eurostat("nama_10_pc", time_format = "raw")
+#'    na_a$time <- eurotime2date(x = na_a$time)
 #'    
 #'    eur_d <- get_eurostat("ert_bil_eur_d", time_format = "raw")
 #'    eur_d$time <- eurotime2date(x = eur_d$time)
@@ -71,8 +71,8 @@ eurotime2date <- function(x, last = FALSE){
   # The date as the last date of the period
   if (last == TRUE) {
     shift <- c("Y" = 367, "S" = 186, "Q" = 96, "M" = 32, "D" = 0)[tcode]  
-    levels(x) <- as.Date(cut(as.Date(levels(x)) + shift, "month")) - 1
+    levels(x) <- lubridate::ymd(cut(lubridate::ymd(levels(x)) + shift, "month")) - 1
   }
-  y <- as.Date(x)
+  y <- lubridate::ymd(x)
   y
 }
